Cache

Struct Cache 

pub struct Cache<T> { /* private fields */ }
A simple cache that stores generated values to avoid recomputation.

Keeps track of the last generated value after clearing.

Implementations

Source

impl<T> Cache<T>

pub fn new() -> Self

Creates a new empty Cache.

pub fn with_group(group: Group) -> Self

Creates a new empty Cache with the given Group.

Caches within the same group may reuse internal rendering storage.

You should generally group caches that are likely to change together.

pub fn group(&self) -> Group

Returns the Group of the Cache.

pub fn put(&self, value: T)

Puts the given value in the Cache.

Notice that, given this is a cache, a mutable reference is not necessary to call this method. You can safely update the cache in rendering code.

pub fn state(&self) -> &RefCell<State<T>>

Returns a reference cell to the internal State of the Cache.

pub fn clear(&self)

Clears the Cache.