pub struct Group { /* private fields */ }Expand description
A cache group.
Caches that share the same group generally change together.
A cache group can be used to implement certain performance optimizations during rendering, like batching or sharing atlases.
Implementations
Sourceimpl Group
impl Group
Sourcepub fn is_singleton(self) -> bool
pub fn is_singleton(self) -> bool
Returns true if the Group can only ever have a
single Cache in it.
This is the default kind of Group assigned when using
Cache::new.
Knowing that a Group will never be shared may be
useful for rendering backends to perform additional
optimizations.