pub enum Gradient {
Linear(Linear),
}Expand description
A fill which linearly interpolates colors along a direction.
For a gradient which can be used as a fill for a background of a widget, see crate::core::Gradient.
Variants
Linear(Linear)
A linear gradient interpolates colors along a direction from its start to its end
point.
Implementations