pub struct Cache<T> { /* private fields */ }Expand description
A simple cache that stores generated values to avoid recomputation.
Keeps track of the last generated value after clearing.
Implementations
Sourceimpl<T> Cache<T>
impl<T> Cache<T>
Sourcepub fn with_group(group: Group) -> Self
pub fn with_group(group: Group) -> Self
Sourcepub fn put(&self, value: T)
pub fn put(&self, value: T)
Puts the given value in the Cache.
Notice that, given this is a cache, a mutable reference is not necessary to call this method. You can safely update the cache in rendering code.